Cheetah.Tests.Pinger module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.Tests.Pinger module

class `Cheetah.Tests.Pinger.` `Pinger`(source=None, namespaces=None, searchList=None, file=None, filter='RawOrEncodedUnicode', filtersLib=<module 'Cheetah.Filters' from '/home/phd/current/projects/cheetah3/cheetah3/Cheetah/Filters.py'>, errorCatcher=None, compilerSettings=Unspecified, _globalSetVars=None, _preBuiltSearchList=None)

  Bases: `Cheetah.Template.Template`

  `ping`()